# To fix paths, Racket performs direct ELF surgery during install. D'oh!
# (see collects/setup/unixstyle-install.rkt)
# That's why we end up with slightly different executables that share the same
# build ID, and this breaks debuginfo extraction.
%define debug_package %{nil}

Name:		racket
Version:	5.3.6
Release:	%mkrel 7
Summary:	Racket is a Scheme implementation
License:	LGPLv2+
Group:		Development/Other
Url:		http://www.racket-lang.org
Source0:	http://download.racket-lang.org/installers/%{version}/racket/%{name}-%{version}-src-unix.tgz
Source1:	racket.png
BuildRequires:	libffi-devel
BuildRequires:	libpng-devel
BuildRequires:	imagemagick
Requires:	%{_lib}png16_16

%define		major %{version}
%define		develname %mklibname %{name} -d

%description
Racket is a Scheme implementation. It implements
the language as described in the Revised^5 Report on the
Algorithmic Language Scheme and adds numerous extensions.

%package -n	%{develname}
Summary:	Headers for developing programs that will use %{name}
Group:		Development/Other
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
This package contains the headers that programmers will need to develop
applications which will use %{name}.

%package -n	g%{name}
Summary:	Racket graphical Scheme implementation
Group:		Development/Other
Requires:	%{name} = %{version}
Requires:	gtk+2.0

%description -n	g%{name}
GRacket is the Racket's graphical Scheme implementation. It embeds and
extends Racket with a graphical user interface (GUI) toolbox.

%package -n	dr%{name}
Summary:	Racket graphical development environment
Group:		Development/Other
Requires:	g%{name} = %{version}

%description -n	dr%{name}
DrRacket is the graphical development environment for creating 
Racket and GRacket applications.

%prep
%setup -q
%autopatch -p1

%build
cd src
%configure2_5x
%make

%install
mkdir -p %{buildroot}
cd src
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
# From time to time parallel "raco setup" gets broken.
# One can uncomment the following line to enforce non-parallel mode:
export PLT_SETUP_OPTIONS="-j 1"
%make_install

# correct installation
install -d -m 755 %{buildroot}%{_datadir}
install -d -m 755 %{buildroot}%{_libdir}/%{name}

# correct perms
find %{buildroot}%{_libdir}/%{name}/collects -type d -exec chmod 755 {} \;

%multiarch_includes %{buildroot}%{_includedir}/racket/mzconfig.h

mkdir -p $RPM_BUILD_ROOT%{_defaultdocdir}/%{name}
mv README $RPM_BUILD_ROOT%{_defaultdocdir}/%{name}

mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications
cat > $RPM_BUILD_ROOT%{_datadir}/applications/drracket.desktop << EOF
[Desktop Entry]
Name=DrRacket
Comment=Scheme IDE
Exec=drracket
Icon=drracket
Terminal=false
Type=Application
StartupNotify=true
Categories=Development;IDE;
EOF

# Install icons

install -d -m755 %{buildroot}%{_datadir}/pixmaps
convert -scale "48x48" %{SOURCE1} %{buildroot}%{_datadir}/pixmaps/drracket.png

for size in 16x16 32x32 48x48 64x64; do
    install -d %{buildroot}%{_iconsdir}/hicolor/$size/apps
    convert -resize $size %{SOURCE1} %{buildroot}%{_iconsdir}/hicolor/$size/apps/drracket.png
done

%files
%doc README
%{_docdir}/%{name}/
%{_libdir}/%{name}
%{_bindir}/*
%{_mandir}/man1/*
%exclude %{_bindir}/gracket
%exclude %{_bindir}/drracket
%exclude %{_mandir}/man1/gracket.1*
%exclude %{_mandir}/man1/drracket.1*
%exclude %{_libdir}/%{name}/collects/mred
%exclude %{_libdir}/%{name}/collects/drracket

%files -n %{develname}
%{_libdir}/libracket3m.a
%{_includedir}/*

%files -n gracket
%{_libdir}/%{name}/collects/mred
%{_bindir}/gracket
%{_mandir}/man1/gracket.1*

%files -n drracket
%{_libdir}/%{name}/collects/drracket
%{_bindir}/drracket
%{_mandir}/man1/drracket.1*
%{_datadir}/pixmaps/drracket.png
%{_iconsdir}/hicolor/*/apps/drracket.png
%{_datadir}/applications/drracket.desktop


%changelog
* Tue Feb 16 2016 umeabot <umeabot> 5.3.6-7.mga6
+ Revision: 962697
- Mageia 6 Mass Rebuild

* Fri Oct 23 2015 daviddavid <daviddavid> 5.3.6-6.mga6
+ Revision: 894421
- add more docs to fix build with latest rpm

* Wed Oct 15 2014 umeabot <umeabot> 5.3.6-5.mga5
+ Revision: 742096
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 5.3.6-4.mga5
+ Revision: 725217
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 5.3.6-3.mga5
+ Revision: 688599
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 5.3.6-2.mga4
+ Revision: 535153
- Mageia 4 Mass Rebuild

* Wed Sep 18 2013 fwang <fwang> 5.3.6-1.mga4
+ Revision: 481252
- do not build shared lib, as suggested by upstream
- new version 5.3.6
- br libpng
- do not build parallel
- do not build shared lib, it is not suggested by upstream
- force libpng16
- use system ffi
- new version 5.3.5

* Sun Jan 13 2013 umeabot <umeabot> 5.3.1-3.mga3
+ Revision: 380151
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Dec 28 2012 mitya <mitya> 5.3.1-2.mga3
+ Revision: 335758
- GUIs don't work without racket itself; don't provide "racket" from libracket
- Various fixes on reqs and provides

* Thu Nov 08 2012 mitya <mitya> 5.3.1-1.mga3
+ Revision: 316509
- New version 5.3.1

* Fri Aug 24 2012 mitya <mitya> 5.3-1.mga3
+ Revision: 283397
- new version 5.3
- drop patch 0 (merged upstream)
- parallel "raco setup" works again

* Sat May 05 2012 mitya <mitya> 5.2.1-1.mga2
+ Revision: 234779
- Update to 5.2.1

* Sat May 05 2012 mitya <mitya> 5.2-1.mga2
+ Revision: 234767
- Fix build
- Import Racket 5.2
- Created package structure for racket.

